@@ -40,15 +40,22 @@ class NpmSource(NvdSource):
         requires = {}
         dependencies = {}
         for pkg in pkg_list:
+            vendor = None
             if isinstance(pkg, dict):
+                vendor = pkg.get("vendor")
                 name = pkg.get("name")
                 version = pkg.get("version")
             else:
                 tmpA = pkg.split("|")
                 version = tmpA[len(tmpA) - 1]
                 name = tmpA[len(tmpA) - 2]
-            requires[name] = version
-            dependencies[name] = {"version": version}
+                if len(tmpA) == 3:
+                    vendor = tmpA[0]
+            key = name
+            if vendor:
+                key = f"{vendor}/{name}"
+            requires[key] = version
+            dependencies[key] = {"version": version}
         payload["requires"] = requires
         payload["dependencies"] = dependencies
         return convert_to_occurrence(serialize_vuln_list(self.fetch(payload)))
@@ -148,10 +155,11 @@ class NpmSource(NvdSource):
             for d in adv_data:
                 self.to_vuln(d, ret_data)
         else:
-            for k, v in adv_data.get("advisories").items():
-                if v["deleted"]:
-                    continue
-                self.to_vuln(v, ret_data)
+            if adv_data.get("advisories"):
+                for k, v in adv_data.get("advisories").items():
+                    if v["deleted"]:
+                        continue
+                    self.to_vuln(v, ret_data)
         return ret_data
 
     def to_vuln(self, v, ret_data):
