@@ -1,6 +1,6 @@
 import importlib
 import re
-from datetime import datetime
+from datetime import datetime, date
 from enum import Enum
 
 from semver import VersionInfo
@@ -18,11 +18,21 @@ BASEVERSION = re.compile(
         (\.
             (?P<patch>0|[1-9]\d*)
         )?
+        (?:[-\.](?P<prerelease>
+            (?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)
+            (?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*
+        ))?
+        (?:-\+(?P<build>
+            [0-9a-zA-Z-]+
+            (?:\.[0-9a-zA-Z-]+)*
+        ))?
         )?
     """,
     re.VERBOSE,
 )
 
+KNOWN_PRERELEASE_STR = ["final", "release", "alpha", "beta", "rc", "latest"]
+
 
 class ClassNotFoundError(Exception):
     """docstring for ClassNotFoundError"""
@@ -269,9 +279,33 @@ def convert_to_semver(version):
     ver = {
         key: 0 if value is None else value for key, value in match.groupdict().items()
     }
+    # Trim based on known prerelease strings
+    if ver.get("prerelease"):
+        pre_str = ver.get("prerelease", "").lower()
+        for s in KNOWN_PRERELEASE_STR:
+            if s in pre_str:
+                ver["prerelease"] = None
+                ver["build"] = None
+                break
+
     ver = VersionInfo(**ver)
     rest = match.string[match.end() :]  # noqa:E203
     number_part = convert_to_num(rest)
+    date_obj = None
+    if "-" in version:
+        try:
+            date_obj = date.fromisoformat(version)
+        except Exception:
+            date_obj = None
+    # Is this a date as used by go packages
+    if date_obj and date_obj.year == ver.major and not ver.minor and not ver.patch:
+        ver = VersionInfo(
+            major=0,
+            minor=0,
+            patch=0,
+            prerelease=int(f"{version.replace('-', '')[:8]}000000"),
+            build=None,
+        )
     if not number_part:
         rest = None
     return ver, rest
@@ -332,8 +366,9 @@ def version_compare(
             min_value = compare_semver.compare(min_semver)
             max_value = compare_semver.compare(max_semver)
             # If we are confident about the versions post upgrade then return True
-            if min_value >= 0 and max_value <= 0:
-                return True
+            min_check = min_value > 0 if is_min_exclude else min_value >= 0
+            max_check = max_value < 0 if is_max_exclude else max_value <= 0
+            return min_check and max_check
 
     compare_ver_build = None
     min_version_build = None
